==> haskell-crypton-connection-0.4.4-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-connection
version:              0.4.4
visibility:           public
id:                   crypton-connection-0.4.4-Euem0yM0Cv6LMDpPbuhAEm
key:                  crypton-connection-0.4.4-Euem0yM0Cv6LMDpPbuhAEm
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-connection
synopsis:             Simple and easy network connection API
description:
    Simple network library for all your connection needs.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  4c326fc5acc22ba31b9f1734aa04a8db
exposed:              True
exposed-modules:      Network.Connection Network.Connection.Internal
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-connection
hs-libraries:         HScrypton-connection-0.4.4-Euem0yM0Cv6LMDpPbuhAEm
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-x509-store-1.6.11-3HJDPoeo1dSJ8A4nqSrxS0
    crypton-x509-system-1.6.7-57zO3vOmVdh8ly154VcTlo
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    socks-0.6.1-4KTV2yLNl7kIQvPy230KQI tls-2.0.6-IakNTBA0JiNDRPputM9FQX

haddock-interfaces:
    /usr/share/doc/haskell-crypton-connection/html/crypton-connection.haddock

haddock-html:         /usr/share/doc/haskell-crypton-connection/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-connection-0.4.5-14-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-connection
version:              0.4.5
visibility:           public
id:                   crypton-connection-0.4.5-CBwSG29ckAMGaPodtkho7w
key:                  crypton-connection-0.4.5-CBwSG29ckAMGaPodtkho7w
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-connection
synopsis:             Simple and easy network connection API
description:
    Simple network library for all your connection needs.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  61f244dbd2a51e66920cdabefe22c1a4
exposed:              True
exposed-modules:      Network.Connection Network.Connection.Internal
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-connection
hs-libraries:         HScrypton-connection-0.4.5-CBwSG29ckAMGaPodtkho7w
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-socks-0.6.2-4dNMoHueHi5AVW063tfWrz
    crypton-x509-store-1.6.11-1zcjSHdk19EHQM8qvNWKQg
    crypton-x509-system-1.6.7-7PfSsfL5yxd9XPi4iirL8E
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    tls-2.0.6-I1Ld4heBgrMIPyOIwAkQZM

haddock-interfaces:
    /usr/share/doc/haskell-crypton-connection/html/crypton-connection.haddock

haddock-html:         /usr/share/doc/haskell-crypton-connection/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
